Learn R Programming

chess2plyrs (version 0.3.0)

all_possibilities: all_possibilities

Description

finds all legal moves for the player moving, and all the squares under attack from the opponent pieces.

Usage

all_possibilities(game)

Value

all chess possibilities

Arguments

game

chess game object (i.e., a list with elements board, turn, history, and fen_history as created by newgame function)