Learn R Programming

chess2plyrs (version 0.3.0)

chess2plyrs-package: chess2plyrs: Chess Game Creation and Tools

Description

A chess program which allows the user to create a game, add moves, check for legal moves and game result, plot the board, take back, read and write FEN (Forsyth–Edwards Notation). A basic chess engine based on minimax is implemented.

Arguments

Author

Maintainer: Luigi Annicchiarico luigi.annic@gmail.com