Learn R Programming

chess2plyrs (version 0.3.0)

game_result: game_result

Description

This function tells if the game is still ongoing, or if a checkamte or stalemate are on the board

Usage

game_result(game)

Value

a message

Arguments

game

chess game object (i.e., a list with elements board, turn, history, and fen_history as created by newgame function)