powered by
finds all legal moves for the player moving, and all the squares under attack from the opponent pieces.
all_possibilities(game)
all chess possibilities
chess game object (i.e., a list with elements board, turn, history, and fen_history as created by newgame function)