powered by
This function tells if the game is still ongoing, or if a checkamte or stalemate are on the board
game_result(game)
a message
chess game object (i.e., a list with elements board, turn, history, and fen_history as created by newgame function)